<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://brewpixel.com
 * @since             1.0.0
 * @package           BrewPixel_Bespoke
 *
 * @wordpress-plugin
 * Plugin Name:       BrewPixel Bespoke
 * Plugin URI:        http://brewpixel.com/brewpixel-bespoke/
 * Description:       This plugin is unique to sonobex.com and provides functions which can be used with future theme changes.
 * Version:           1.0.1
 * Author:            Martin Goldie, BrewPixel
 * Author URI:        http://brewpixel.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       brewpixel-bespoke
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

add_action( 'plugins_loaded', 'bp_add_custom_post_types' );

/**
 * Add custom post types.
 *
 * @since    1.0.0
 */
function bp_add_custom_post_types() {

	if ( class_exists( '\BrewPixel\BrewPress\BrewPress' ) ) {
		// Post type names must be between 1 and 20 characters in length.
		$bpperson = new \BrewPixel\BrewPress\CustomPostType
		\CreateCustomPostType(
			'bpperson',
			[
				'singular_name' => 'Person',
				'plural_name'   => 'People',
			],
			[
				'supports'     => [
					'title',
					'editor',
					'thumbnail',
					'excerpt',
					'page-attributes',
				],
				'rewrite'      => [
					'slug'       => 'people',
					'with_front' => false,
				],
				'hierarchical' => true,
			]
		);

		function bp_person_query( $query ) {
			if ( ! is_admin() && $query->is_main_query() && is_post_type_archive(
							'bpperson' )
			) {
				$query->set( 'post_type', 'bpperson' );
				$query->set( 'orderby', 'menu_order' );
				$query->set( 'order', 'ASC' );
				return;
			}
		}

		add_action( 'pre_get_posts', 'bp_person_query', 1 );

		/**
		 * Rename the "Feature Image"
		 */
		function bp_image_metabox() {
			remove_meta_box( 'postimagediv', 'bpperson', 'side' );
			add_meta_box(
				'postimagediv',
				__( 'Person\'s Image' ),
				'post_thumbnail_meta_box',
				'bpperson',
				'side',
				'default'
			);
		}

		add_action( 'do_meta_boxes', 'bp_image_metabox' );
		/**
		 * Use this function to add instructions to the "Feature Image" metabox.
		 *
		 * @param string $content The HTML content you wish to add.
		 *
		 * @return string
		 */
		function image_size_html( $content = '' ) {
			global $post_ID;

			$post_type = get_post_type( $post_ID );

			switch ( $post_type ) {
				case 'bpperson' :
					$dim                       = 'Image Height: 480 pixels';
					$set_featured_image        = 'Set Person\'s Image';
					$remove_featured_image     = 'Remove Person\'s Image';
					$admin_featured_image_size = '730';
					break;
				default :
					$dim                   = '';
					$set_featured_image    = 'Set featured image';
					$remove_featured_image = 'Remove featured image';
			}

			$content = str_replace(
				esc_attr__( 'Set featured image' ),
				esc_attr__( $set_featured_image ),
				$content
			);
			// $content = str_replace(esc_attr__( '266' ), esc_attr__( $admin_featured_image_size ), $content);
			$content = str_replace(
				esc_attr__( 'Remove featured image' ),
				esc_attr__( $remove_featured_image ),
				$content
			);

			return $content .= $dim;
		}

		add_filter( 'admin_post_thumbnail_html', 'image_size_html', 9999, 1 );

		/**
		 * Change the default "Enter title here" text
		 *
		 * @param string $title The text for the title field.
		 *
		 * @return string
		 */
		function bpperson_post_title( $title ) {
			$screen = get_current_screen();
			if ( 'bpperson' == $screen->post_type ) {
				$title = 'Enter person\'s name here';
			}

			return $title;
		}

		add_filter( 'enter_title_here', 'bpperson_post_title' );

		/*
		* SETTINGS
		*/

		/*
		* METABOXES
		*/
		$bp_person_info_text = new \BrewPixel\BrewPress\MetaBox
		\Metabox(
			'bpperson',
			'Info',
			'side',
			'high',
			array(
				'Job Title' => 'text',
				'LinkedIn'  => 'url',
			) );
	}
}

/**
 * Check to make sure the BrewPress plugin has been installed and activated.
 */
function bp_bespoke_check_plugin_requirements() {
	if ( false === class_exists( '\BrewPixel\BrewPress\BrewPress' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		deactivate_plugins( plugin_basename( __FILE__ ) );
		$html = '<div class="error">';
		$html .= '<p>';
		$html .= __(
			'There was a problem activating the sonobex.com bespoke plugin.',
			'brewpixel-bespoke'
		);
		$html .= '</p>';
		$html .= __(
			'This plugin requires that BrewPress plugin be activated. Please try again. Sorry about that.',
			'brewpixel-bespoke'
		);
		$html .= '</div><!-- /.updated -->';
		wp_die( wp_kses_post( $html ) );
	}
}

add_action( 'plugins_loaded', 'bp_bespoke_check_plugin_requirements' );

// Pre-existing code below (before 2015-09-10).

function sonobex_learn_more_section( $atts, $content ) {
	return '<div class="sonobex-learn-more-section">' . do_shortcode( $content ) . '</div>';
}

function sonobex_learn_more_button( $atts, $content ) {
	return '<div class="sonobex-learn-more-button">' . do_shortcode( $content ) . '</div>';
}

function sonobex_trademark( $atts, $content ) {
	return '<span class="sonobex-trademark">TM</span>';
}

add_shortcode( 'sonobex_learn_more_button', 'sonobex_learn_more_button' );
add_shortcode( 'sonobex_learn_more_section', 'sonobex_learn_more_section' );
add_shortcode( 'sonobex_trademark', 'sonobex_trademark' );

add_filter( 'the_content', 'sonobex_the_content', 11 );
add_filter( 'the_title', 'sonobex_the_content', 11 );

function sonobex_the_content( $content ) {
	return str_replace( '™', '<span class="sonobex-trademark">TM</span>', str_replace( '&#8217;', "'", str_replace( '’', "'", str_replace( '&#8230;', '...', str_replace( '&#8220;', '"', str_replace( '&#8221;', '"', str_replace( '“', '"', str_replace( '”', '"', $content ) ) ) ) ) ) ) );
}

function sonobex_images( $atts, $content = null ) {
	$output = '<script type="text/javascript">
            jQuery(window).load(function() {
              jQuery("#carousel").flexslider({
                animation: "slide",
                smoothHeight : false,
                directionNav: true,
                controlNav: false,
                itemWidth: 258.75,
                itemMargin: 20,
                minItems: 2,
                maxItems: 5
              });
            });
          </script>';
	$output .= '<div id="carousel" class="flexslider-images"><ul class="slides">';
	$output .= do_shortcode( $content );
	$output .= '</ul></div>';

	return $output;
}

add_shortcode( 'sonobex_images', 'sonobex_images' );

function sonobex_members( $atts, $content = null ) {
	$include = get_pages( array( 'include' => 5861, 'post_status' => 'publish,private' ) );
	$content = apply_filters( 'the_content', $include[0]->post_content );
	$content = preg_replace( '/^\s*\<ul\>/u', '', preg_replace( '/\<\/ul\>\s*$/u', '', $content ) );
	if ( isset( $atts['style'] ) ) {
		$content = '<ul class="sonobex-members-' . $atts['style'] . '">' . ( ( $content ) ) . '</ul>';
	}

	return $content;
}

add_shortcode( 'sonobex_members', 'sonobex_members' );

function sonobex_richer_z_ind_workaround( $content ) {
	richer_section( array( 'z_ind_reset' => true ) );

	return $content;
}

add_filter( 'get_the_excerpt', 'sonobex_richer_z_ind_workaround', 100000 );
